<?php
/**
 * @package AWPCP\Admin\Importer
 */

class AWPCP_ImportListingsAdminPage {

    private $import_session = false;

    private $import_sessions_manager;
    private $csv_importer_factory;
    private $form_steps;
    private $javascript;
    private $settings;

    public function __construct( $import_sessions_manager, $csv_importer_factory, $form_steps, $javascript, $settings ) {
        $this->import_sessions_manager = $import_sessions_manager;
        $this->csv_importer_factory = $csv_importer_factory;
        $this->form_steps              = $form_steps;
        $this->javascript = $javascript;
        $this->settings = $settings;
    }

	public function enqueue_scripts() {
		wp_enqueue_style('awpcp-jquery-ui');
		wp_enqueue_style( 'select2' );
  		wp_enqueue_script( 'awpcp-admin-import' );
	}

    public function dispatch() {
        echo $this->handle_request();
    }

    private function handle_request() {
        if ( awpcp_get_var( array( 'param' => 'cancel' ), 'post' ) || awpcp_get_var( array( 'param' => 'finish' ), 'post' ) ) {
            return $this->delete_current_import_session();
        }

        $import_session = $this->get_import_session();

        if ( ! is_null( $import_session ) && ( $import_session->is_ready() || $import_session->is_in_progress() ) ) {
            $step = 'execute';
        } else if ( ! is_null( $import_session ) ) {
            $step = 'configure';
        } else {
            $step = awpcp_get_var( array( 'param' => 'step', 'default' => 'upload-files' ), 'get' );
        }

        if ( $step == 'upload-files' ) {
            return $this->do_upload_files_step();
        } else if ( $step == 'configure' ) {
            return $this->do_configuration_step();
        } else if ( $step == 'execute' ) {
            return $this->do_execute_step();
        }
    }

    private function delete_current_import_session() {
        awpcp_rmdir( $this->get_import_session()->get_working_directory() );

        $this->import_sessions_manager->delete_current_import_session();

        return $this->show_upload_files_form();
    }

    private function get_import_session() {
        if ( $this->import_session === false ) {
            $this->import_session = $this->import_sessions_manager->get_current_import_session();
        }

        return $this->import_session;
    }

    private function do_upload_files_step() {
        if ( awpcp_get_var( array( 'param' => 'upload_files' ), 'post' ) ) {
            return $this->upload_files();
        }

        return $this->show_upload_files_form();
    }

    private function upload_files() {
        $import_session = $this->import_session = $this->import_sessions_manager->create_import_session();

        $working_directory = $this->get_working_directory( $import_session->get_id() );
        $images_directory = null;

        $form_data = array(
            'images_source' => awpcp_get_var( array( 'param' => 'images_source' ), 'post' ),
            'local_path'    => awpcp_get_var( array( 'param' => 'local_path' ), 'post' ),
        );

        if ( $_FILES['csv_file']['error'] != UPLOAD_ERR_OK ) {
			// phpcs:ignore WordPress.Security.ValidatedSanitizedInput
            $file_error              = awpcp_uploaded_file_error( $_FILES['csv_file'] );
            $form_errors['csv_file'] = $file_error[1];

			// phpcs:ignore WordPress.Security.ValidatedSanitizedInput
        } else if ( substr( $_FILES['csv_file']['name'], -4 ) !== '.csv' ) {
            $form_errors['csv_file'] = __( "The uploaded file doesn't look like a CSV file. Please upload a valid CSV file.", 'another-wordpress-classifieds-plugin' );

			// phpcs:ignore WordPress.Security.ValidatedSanitizedInput
        } else if ( ! @move_uploaded_file( $_FILES['csv_file']['tmp_name'], "$working_directory/source.csv" ) ) {
            $form_errors['csv_file'] = __( 'There was an error moving the uploaded CSV file to a proper location.', 'another-wordpress-classifieds-plugin' );
        }

        $uploads_dir = $this->settings->get_runtime_option( 'awpcp-uploads-dir' );

        if ( $form_data['images_source'] == 'zip' ) {
            if ( ! in_array( $_FILES['zip_file']['error'], array( UPLOAD_ERR_OK, UPLOAD_ERR_NO_FILE ) ) ) {
				// phpcs:ignore WordPress.Security.ValidatedSanitizedInput
                $file_error              = awpcp_uploaded_file_error( $_FILES['zip_file'] );
                $form_errors['zip_file'] = $file_error[1];

				// phpcs:ignore Generic.CodeAnalysis.EmptyStatement.DetectedIf
            } else if ( $_FILES['zip_file']['error'] == UPLOAD_ERR_NO_FILE ) {
                // all good...

				// phpcs:ignore WordPress.Security.ValidatedSanitizedInput
            } else if ( substr( $_FILES['zip_file']['name'], -4 ) !== '.zip' ) {
                $form_errors['zip_file'] = __( "The uploaded file doesn't look like a ZIP file. Please upload a valid ZIP file.", 'another-wordpress-classifieds-plugin' );

				// phpcs:ignore WordPress.Security.ValidatedSanitizedInput
            } else if ( ! @move_uploaded_file( $_FILES['zip_file']['tmp_name'], "$working_directory/images.zip" ) ) {
                $form_errors['zip_file'] = __( 'There was an error moving the uploaded ZIP file to a proper location.', 'another-wordpress-classifieds-plugin' );
            }

            if ( ! isset( $form_errors['zip_file'] ) ) {
                require_once( ABSPATH . 'wp-admin/includes/class-pclzip.php' );

                $images_directory = $this->get_images_directory( $working_directory );

                $zip = new PclZip( "$working_directory/images.zip" );
                $zip_contents = $zip->extract( PCLZIP_OPT_EXTRACT_AS_STRING );

                if ( ! is_array( $zip_contents ) ) {
                    $form_errors['zip_file'] = __( 'Incompatible ZIP Archive', 'another-wordpress-classifieds-plugin' );
                } else if ( 0 === count( $zip_contents ) ) {
                    $form_errors['zip_file'] = __( 'Empty ZIP Archive', 'another-wordpress-classifieds-plugin' );
                }

                foreach ( $zip_contents as $item ) {
                    // ignore folder and don't extract the OS X-created __MACOSX directory files
                    if ( $item['folder'] || '__MACOSX/' === substr( $item['filename'], 0, 9 ) ) {
                        continue;
                    }

                    // don't extract files with a filename starting with . (like .DS_Store)
                    if ( '.' === substr( basename( $item['filename'] ), 0, 1 ) ) {
                        continue;
                    }

                    $path = $images_directory . DIRECTORY_SEPARATOR . $item['filename'];

                    // if file is inside a directory, create it first
                    if ( dirname( $item['filename'] ) !== '.' ) {
                        wp_mkdir_p( dirname( $path ) );
                    }

                    // extract file
                    if ( $file_handler = @fopen( $path, 'w' ) ) {
                        fwrite( $file_handler, $item['content'] );
                        fclose( $file_handler );
                    } else {
                        $message = __( 'Could not write temporary file %s', 'another-wordpress-classifieds-plugin' );
                        $form_errors['unzip'][] = sprintf( $message, $path );
                    }
                }
            }
        } else if ( $form_data['images_source'] == 'local' ) {
            $local_directory = realpath( $uploads_dir . DIRECTORY_SEPARATOR . str_replace( '..', '', $form_data['local_path'] ) );

            if ( strpos( $local_directory, $uploads_dir ) !== 0 || strpos( $local_directory, $uploads_dir ) === false ) {
                $form_errors['local_path'] = __( 'The specified directory is not a valid path.', 'another-wordpress-classifieds-plugin' );
            } else if ( ! is_dir( $local_directory ) ) {
                $form_errors['local_path'] = __( 'The specified directory does not exists.', 'another-wordpress-classifieds-plugin' );
            } else {
                $images_directory = $local_directory;
            }
        }

        if ( empty( $form_errors ) ) {
            $import_session->set_working_directory( $working_directory );
            $import_session->set_images_directory( $images_directory );

            $csv_importer = $this->csv_importer_factory->create_importer( $import_session );

            $import_session->set_data( 'number_of_rows', $csv_importer->count_rows() );
            $import_session->set_status( 'configuration' );

            $this->import_sessions_manager->update_current_import_session( $import_session );

            return $this->show_configuration_form();
        }

        return $this->show_upload_files_form( $form_data, $form_errors );
    }

    private function get_working_directory( $session_id ) {
        $uploads_directories = awpcp_setup_uploads_dir();

        $import_dir = str_replace( 'thumbs', 'import', $uploads_directories[1] );
        $working_directory = $import_dir . $session_id;

        if ( $this->create_directory( $working_directory ) ) {
            return $working_directory;
        }

        return false;
    }

    private function create_directory( $directory ) {
        list( $images_dir ) = awpcp_setup_uploads_dir();

        if ( ! is_dir( $directory ) ) {
            umask( 0 );
            wp_mkdir_p( $directory );
            @chown( $directory, fileowner( $images_dir ) );
        }

        return file_exists( $directory );
    }

    private function get_images_directory( $working_directory ) {
        $images_directory = $working_directory . DIRECTORY_SEPARATOR . 'images';

        if ( $this->create_directory( $images_directory ) ) {
            return $images_directory;
        }

        return false;
    }

    private function show_upload_files_form( $form_data = array(), $form_errors = array() ) {
        $params = array(
            'form_steps' => $this->form_steps->render( 'upload-files' ),
            'form_data' => wp_parse_args( $form_data, array(
                'images_source' => 'none',
                'local_path' => '',
            ) ),
            'form_errors' => $form_errors,
        );

        $template = AWPCP_DIR . '/templates/admin/import-listings-admin-page-upload-files-form.tpl.php';

        return awpcp_render_template( $template, $params );
    }

    private function do_configuration_step() {
        if ( awpcp_get_var( array( 'param' => 'configure' ), 'post' ) ) {
            return $this->save_configuration();
        }

        return $this->show_configuration_form();
    }

    private function save_configuration() {
        $import_session = $this->get_import_session();

        if ( is_null( $import_session ) ) {
            return $this->show_upload_files_form();
        }

        if ( awpcp_get_var( array( 'param' => 'test_import' ), 'post' ) ) {
            $import_session->set_mode( 'test' );
        } else {
            $import_session->set_mode( 'live' );
        }

        if ( awpcp_get_var( array( 'param' => 'define_default_user' ), 'post' ) ) {
            $default_user = awpcp_get_var( array( 'param' => 'default_user' ), 'post' );
        } else {
            $default_user = null;
        }

        $import_session->set_params( array(
            'date_format'        => awpcp_get_var( array( 'param' => 'date_format' ), 'post' ),
            'category_separator' => awpcp_get_var( array( 'param' => 'category_separator' ), 'post' ),
            'time_separator'     => awpcp_get_var( array( 'param' => 'time_separator' ), 'post' ),
            'images_separator'   => awpcp_get_var( array( 'param' => 'images_separator' ), 'post' ),
            'listing_status'     => awpcp_get_var( array( 'param' => 'listing_status' ), 'post' ),
            'create_missing_categories' => awpcp_get_var( array( 'param' => 'create_missing_categories' ), 'post' ),
            'assign_listings_to_user' => awpcp_get_var( array( 'param' => 'assign_listings_to_user' ), 'post' ),
            'default_user'       => $default_user,
            'default_start_date' => awpcp_get_var( array( 'param' => 'default_start_date' ), 'post' ),
            'default_end_date'   => awpcp_get_var( array( 'param' => 'default_end_date' ), 'post' ),
        ) );

        $import_session->set_status( 'ready' );

        $this->import_sessions_manager->update_current_import_session( $import_session );

        return $this->show_import_form();
    }

    private function show_configuration_form( $form_data = array(), $form_errors = array() ) {
        $import_session = $this->get_import_session();

        $form_data = array_merge( $form_data, $import_session->get_params() );

        $define_default_dates = ! empty( $form_data['default_start_date'] ) || ! empty( $form_data['default_end_date'] );
        $define_default_user = ! empty( $form_data['default_user'] );

        $params = array(
            'form_steps'  => $this->form_steps->render( 'configuration' ),
            'form_data' => wp_parse_args( $form_data, array(
                'define_default_dates' => $define_default_dates,
                'default_start_date' => '',
                'default_end_date' => '',
                'date_format'          => 'auto',
                'listing_status' => 'default',
                'time_separator' => ':',
                'date_separator' => '/', // For reverse compatibility with custom template.
                'category_separator' => ';',
                'images_separator' => ';',
                'create_missing_categories' => false,
                'assign_listings_to_user' => true,
                'define_default_user' => $define_default_user,
                'default_user' => null,
            ) ),
            'form_errors' => $form_errors,
        );

        $template = AWPCP_DIR . '/templates/admin/import-listings-admin-page-configuration-form.tpl.php';

        return awpcp_render_template( $template, $params );
    }

    private function do_execute_step() {
        $import_session = $this->get_import_session();

        if ( awpcp_get_var( array( 'param' => 'change_configuration' ), 'post' ) ) {
            $import_session->set_status( 'configuration' );
            $import_session->set_data( 'number_of_rows_imported', 0 );
            $import_session->set_data( 'number_of_rows_rejected', 0 );
            $import_session->set_data( 'last_row_processed', 0 );
            $import_session->clear_errors();

            $this->import_sessions_manager->update_current_import_session( $import_session );

            return $this->show_configuration_form();
        }

        return $this->show_import_form();
    }

    private function show_import_form() {
        $import_session = $this->get_import_session();

        $this->javascript->set( 'csv-import-session', array(
            'numberOfRows' => $import_session->get_number_of_rows(),
            'numberOfRowsImported' => $import_session->get_number_of_rows_imported(),
            'numberOfRowsRejected' => $import_session->get_number_of_rows_rejected(),
        ) );

        $this->javascript->localize( 'csv-import-session', array(
            'progress-report' => __( '(<percentage>) <number-of-rows-processed> of <number-of-rows> rows processed. <number-of-rows-imported> rows imported and <number-of-rows-rejected> rows rejected.', 'another-wordpress-classifieds-plugin' ),
            'message-description' => _x( '<message-type> in line <message-line>', 'description for messages used to show feedback for the Import Listings operation', 'another-wordpress-classifieds-plugin' ),
        ) );

        $is_test_mode_enabled = $import_session->is_test_mode_enabled();

        $params = [
            'form_steps'        => $this->form_steps->render( 'import', [ 'test_mode_enabled' => $is_test_mode_enabled ] ),
            'test_mode_enabled' => $is_test_mode_enabled,
        ];

        if ( $import_session->is_test_mode_enabled() ) {
            $params['action_name'] = _x( 'Test Import', 'text for page subtitle and submit button', 'another-wordpress-classifieds-plugin' );
        } else {
            $params['action_name'] = _x( 'Import', 'text for page subtitle and submit button', 'another-wordpress-classifieds-plugin' );
        }

        $template = AWPCP_DIR . '/templates/admin/import-listings-admin-page-import-form.tpl.php';

        return awpcp_render_template( $template, $params );
    }
}
